@@ -28,7 +28,10 @@
  * with a particular device or vendor.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -77,9 +80,9 @@ typedef FILE * pci_id_file;
 static pci_id_file
 pci_id_file_open(void)
 {
+#ifndef __sun
     pci_id_file result;
 
-#ifndef __sun
     result = fopen(PCIIDS_PATH "/pci.ids", "re");
     if (result)
         return result;
@@ -151,6 +154,10 @@ insert( uint16_t vendor )
 
     if ( tree == NULL ) {
 	tree = calloc( 1, sizeof( struct pci_id_node ) );
+
+	if ( tree == NULL )
+	    return NULL;
+
 	tree->bits = 4;
     }
 
@@ -172,6 +179,9 @@ insert( uint16_t vendor )
 		struct pci_id_node * child =
 		    calloc( 1, sizeof( struct pci_id_node ) );
 
+		if ( tree == NULL )
+		    return NULL;
+
 		child->bits = 4;
 
 		n->children[ idx ] = child;
@@ -180,6 +190,9 @@ insert( uint16_t vendor )
 		struct pci_id_leaf * leaf =
 		    calloc( 1, sizeof( struct pci_id_leaf ) );
 
+		if ( tree == NULL )
+		    return NULL;
+
 		leaf->vendor = vendor;
 
 		n->children[ idx ] = (struct pci_id_node *) leaf;
